@@ -47,7 +47,7 @@ def exclude_ppss_auth_tables(config=None,sectionname='alembic:exclude',asadict=T
     if type_ == "table":
         for pattern in exclude_tables:
             if pattern.match(name):
-                l.info("excluded {}({}) because mathes pattern {}".format(name, type_,pattern) )
+                l.warning("excluded {}({}) because matches pattern {}".format(name, type_,pattern) )
                 return False
     l.info("{}({}) passed all patterns".format(name,type_))
     return True
@@ -68,9 +68,13 @@ def exclude_ppss_auth_tables(config=None,sectionname='alembic:exclude',asadict=T
     exclude_tables += tables
   if (config is None) or merge:
     tables = []
-    for table in Base.__subclasses__():
-      l.debug("name {}".format(table.__tablename__))
-      tables.append (re.compile("^" + table.__tablename__ + "$") )
+    for table in Base.metadata.tables:
+      l.debug("adding name {}".format(table))
+      tables.append (re.compile("^" + table + "$") )
+    #for table in Base.__subclasses__():
+    #  l.debug("adding name {}".format(table.__tablename__))
+    #  tables.append (re.compile("^" + table.__tablename__ + "$") )
+    tables.append(re.compile("^ppss_auth_alembic_version$"))
     exclude_tables += tables
   l.info("excluded tables:{}".format(exclude_tables))
   
